@@ -3,11 +3,14 @@ import hashlib
 import hmac
 import logging
 import socket
-import time
-import ssl
 import sys
 import json
 
+try:
+    import ssl
+except ImportError:
+    ssl = None
+
 from multiprocessing import Process, Manager, Queue, pool
 from threading import RLock, Thread
 from datetime import datetime
@@ -36,7 +39,7 @@ logging.basicConfig()
 logger = logging.getLogger()
 
 DEBUG = False
-VERSION = "0.4.3"
+VERSION = "0.4.5"
 
 DEFAULT_GROUP_NAME = "DEFAULT_GROUP"
 DEFAULT_NAMESPACE = ""
@@ -579,7 +582,7 @@ class ACMClient:
 
         if self.puller_mapping is None:
             logger.debug("[add-watcher] pulling should be initialized")
-            self._int_pulling()
+            self._init_pulling()
 
         if cache_key in self.puller_mapping:
             logger.debug("[add-watcher] key:%s is already in pulling" % cache_key)
@@ -588,7 +591,7 @@ class ACMClient:
         for key, puller_info in self.puller_mapping.items():
             if len(puller_info[1]) < self.pulling_config_size:
                 logger.debug("[add-watcher] puller:%s is available, add key:%s" % (puller_info[0], cache_key))
-                puller_info[1].append(key)
+                puller_info[1].append(cache_key)
                 self.puller_mapping[cache_key] = puller_info
                 break
         else:
@@ -711,12 +714,14 @@ class ACMClient:
                     logger.debug("[do-pulling] new key added: %s" % cache_key)
                     cache_data = CacheData(cache_key, self)
                     cache_pool[cache_key] = cache_data
+                else:
+                    unused_keys.remove(cache_key)
                 if cache_data.is_init:
                     contains_init_key = True
                 data_id, group, namespace = parse_key(cache_key)
                 probe_update_string += WORD_SEPARATOR.join(
                     [data_id, group, cache_data.md5 or "", self.namespace]) + LINE_SEPARATOR
-                unused_keys.remove(cache_key)
+
             for k in unused_keys:
                 logger.debug("[do-pulling] %s is no longer watched, remove from cache" % k)
                 cache_pool.pop(k)
@@ -750,7 +755,7 @@ class ACMClient:
                 queue.put((cache_key, cache_data.content, cache_data.md5))
 
     @synchronized_with_attr("pulling_lock")
-    def _int_pulling(self):
+    def _init_pulling(self):
         if self.puller_mapping is not None:
             logger.info("[init-pulling] puller is already initialized")
             return
